'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var path = _interopDefault(require('path'));
var legacy = _interopDefault(require('@vitejs/plugin-legacy'));
var react = _interopDefault(require('@vitejs/plugin-react'));
var eslintPlugin = _interopDefault(require('vite-plugin-eslint'));
var tsconfigPaths = _interopDefault(require('vite-tsconfig-paths'));
var StylelintPlugin = _interopDefault(require('vite-plugin-stylelint'));
var vitePluginHtml = require('vite-plugin-html');

/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

function __spreadArray(to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
}

var os = require('os');
var fs = require('fs');
var NEWLINE = '\n';
var RE_INI_KEY_VAL = /^\s*([\w.-]+)\s*=\s*("[^"]*"|'[^']*'|.*?)(\s+#.*)?$/;
var RE_NEWLINES = /\\n/g;
var NEWLINES_MATCH = /\r\n|\n|\r/;
var main$1 = { exports: {} };
// Parses src into an Object
function parse(src, options) {
    var debug = Boolean(options && options.debug);
    var multiline = Boolean(options && options.multiline);
    var obj = {};
    // convert Buffers before splitting into lines and processing
    var lines = src.toString().split(NEWLINES_MATCH);
    for (var idx = 0; idx < lines.length; idx++) {
        var line = lines[idx];
        // matching "KEY' and 'VAL' in 'KEY=VAL'
        var keyValueArr = line.match(RE_INI_KEY_VAL);
        // matched?
        if (keyValueArr != null) {
            var key = keyValueArr[1];
            // default undefined or missing values to empty any
            var val = (keyValueArr[2] || '');
            var end = val.length - 1;
            var isDoubleQuoted = val[0] === '"' && val[end] === '"';
            var isSingleQuoted = val[0] === "'" && val[end] === "'";
            var isMultilineDoubleQuoted = val[0] === '"' && val[end] !== '"';
            var isMultilineSingleQuoted = val[0] === "'" && val[end] !== "'";
            // if parsing line breaks and the value starts with a quote
            if (multiline && (isMultilineDoubleQuoted || isMultilineSingleQuoted)) {
                var quoteChar = isMultilineDoubleQuoted ? '"' : "'";
                val = val.substring(1);
                while (idx++ < lines.length - 1) {
                    line = lines[idx];
                    end = line.length - 1;
                    if (line[end] === quoteChar) {
                        val += NEWLINE + line.substring(0, end);
                        break;
                    }
                    val += NEWLINE + line;
                }
                // if single or double quoted, remove quotes
            }
            else if (isSingleQuoted || isDoubleQuoted) {
                val = val.substring(1, end);
                // if double quoted, expand newlines
                if (isDoubleQuoted) {
                    val = val.replace(RE_NEWLINES, NEWLINE);
                }
            }
            else {
                // remove surrounding whitespace
                val = val.trim();
            }
            obj[key] = val;
        }
        else if (debug) {
            var trimmedLine = line.trim();
            // ignore empty and commented lines
            if (trimmedLine.length && trimmedLine[0] !== '#') {
                console.log("Failed to match key and value when parsing line ".concat(idx + 1, ": ").concat(line));
            }
        }
    }
    return obj;
}
function lookupFile(dir, formats, options) {
    for (var _i = 0, formats_1 = formats; _i < formats_1.length; _i++) {
        var format = formats_1[_i];
        var fullPath = path.join(dir, format);
        if (fs.existsSync(fullPath) && fs.statSync(fullPath).isFile()) {
            var result = (options === null || options === void 0 ? void 0 : options.pathOnly)
                ? fullPath
                : fs.readFileSync(fullPath, 'utf-8');
            if (!(options === null || options === void 0 ? void 0 : options.predicate) || options.predicate(result)) {
                return result;
            }
        }
    }
    var parentDir = path.dirname(dir);
    if (parentDir !== dir &&
        (!(options === null || options === void 0 ? void 0 : options.rootDir) || parentDir.startsWith(options === null || options === void 0 ? void 0 : options.rootDir))) {
        return lookupFile(parentDir, formats, options);
    }
}
function resolveHome(envPath) {
    return envPath[0] === '~' ? path.join(os.homedir(), envPath.slice(1)) : envPath;
}
var dotenvExpand = function (config) {
    // if ignoring process.env, use a blank object
    var environment = config.ignoreProcessEnv ? {} : process.env;
    var interpolate = function (envValue) {
        var matches = envValue.match(/(.?\${?(?:[a-zA-Z0-9_]+)?}?)/g) || [];
        return matches.reduce(function (newEnv, match) {
            var parts = /(.?)\${?([a-zA-Z0-9_]+)?}?/g.exec(match);
            var prefix = parts[1];
            var value, replacePart;
            if (prefix === '\\') {
                replacePart = parts[0];
                value = replacePart.replace('\\$', '$');
            }
            else {
                var key = parts[2];
                replacePart = parts[0].substring(prefix.length);
                // process.env value 'wins' over .env file's value
                value = environment.hasOwnProperty(key) ? environment[key] : (config.parsed[key] || '');
                // Resolve recursive interpolations
                value = interpolate(value);
            }
            return newEnv.replace(replacePart, value);
        }, envValue);
    };
    for (var configKey in config.parsed) {
        var value = environment.hasOwnProperty(configKey) ? environment[configKey] : config.parsed[configKey];
        config.parsed[configKey] = interpolate(value);
    }
    for (var processKey in config.parsed) {
        environment[processKey] = config.parsed[processKey];
    }
    return config;
};
var main = dotenvExpand;
// Populates process.env from .env file
function config(options) {
    var dotenvPath = path.resolve(process.cwd(), '.env');
    var encoding = 'utf8';
    var debug = Boolean(options && options.debug);
    var override = Boolean(options && options.override);
    var multiline = Boolean(options && options.multiline);
    if (options) {
        if (options.path != null) {
            dotenvPath = resolveHome(options.path);
        }
        if (options.encoding != null) {
            encoding = options.encoding;
        }
    }
    try {
        // specifying an encoding returns a any instead of a buffer
        var parsed_1 = DotenvModule.parse(fs.readFileSync(dotenvPath, { encoding: encoding }), { debug: debug, multiline: multiline });
        Object.keys(parsed_1).forEach(function (key) {
            if (!Object.prototype.hasOwnProperty.call(process.env, key)) {
                process.env[key] = parsed_1[key];
            }
            else {
                if (override === true) {
                    process.env[key] = parsed_1[key];
                }
                if (debug) {
                    if (override === true) {
                        console.log("\"".concat(key, "\" is already defined in `process.env` and WAS overwritten"));
                    }
                    else {
                        console.log("\"".concat(key, "\" is already defined in `process.env` and was NOT overwritten"));
                    }
                }
            }
        });
        return { parsed: parsed_1 };
    }
    catch (e) {
        if (debug) {
            console.log("Failed to load ".concat(dotenvPath, " ").concat(e.message));
        }
        return { error: e };
    }
}
var DotenvModule = {
    config: config,
    parse: parse
};
main$1.exports.config = DotenvModule.config;
main$1.exports.parse = DotenvModule.parse;
main$1.exports = DotenvModule;
function arraify(target) {
    return Array.isArray(target) ? target : [target];
}
var loadEnv = function (mode, envDir, prefixes) {
    var _a;
    if (prefixes === void 0) { prefixes = 'VITE_'; }
    if (mode === 'local') {
        throw new Error("\"local\" cannot be used as a mode name because it conflicts with " +
            "the .local postfix for .env files.");
    }
    var _prefixes = arraify(prefixes);
    var env = {};
    var envFiles = [
        /** mode local file */ ".env.".concat(mode, ".local"),
        /** mode file */ ".env.".concat(mode),
        /** local file */ ".env.local",
        /** default file */ ".env"
    ];
    var _loop_1 = function (key) {
        if (_prefixes.some(function (prefix) { return key.startsWith(prefix); }) &&
            env[key] === undefined) {
            env[key] = process.env[key];
        }
    };
    // check if there are actual env variables starting with VITE_*
    // these are typically provided inline and should be prioritized
    for (var key in process.env) {
        _loop_1(key);
    }
    for (var _i = 0, envFiles_1 = envFiles; _i < envFiles_1.length; _i++) {
        var file = envFiles_1[_i];
        var path_1 = lookupFile(envDir, [file], { pathOnly: true, rootDir: envDir });
        if (path_1) {
            var parsed = main$1.exports.parse(fs.readFileSync(path_1), {
                debug: ((_a = process.env.DEBUG) === null || _a === void 0 ? void 0 : _a.includes('vite:dotenv')) || undefined
            });
            // let environment variables use each other
            main({
                parsed: parsed,
                // prevent process.env mutation
                ignoreProcessEnv: true
            });
            var _loop_2 = function (key, value) {
                if (_prefixes.some(function (prefix) { return key.startsWith(prefix); }) &&
                    env[key] === undefined) {
                    env[key] = value;
                }
                else if (key === 'NODE_ENV' &&
                    process.env.VITE_USER_NODE_ENV === undefined) {
                    // NODE_ENV override in .env file
                    process.env.VITE_USER_NODE_ENV = value;
                }
            };
            // only keys that start with prefix are exposed to client
            for (var _b = 0, _c = Object.entries(parsed); _b < _c.length; _b++) {
                var _d = _c[_b], key = _d[0], value = _d[1];
                _loop_2(key, value);
            }
        }
    }
    return env;
};

var fs$1 = require('fs');
function modifyDistPath(obj) {
    var root = obj.root, outDir = obj.outDir, html = obj.html, assets = obj.assets;
    return {
        name: 'modifyDistPath',
        closeBundle: function () {
            var fileName = '/index.html';
            /** 转移html文件 */
            fs$1.mkdir(path.join(root + html), function (err) {
                if (err) {
                    return console.error(err);
                }
                fs$1.renameSync(path.join(outDir + fileName), path.join(root + html + fileName));
            });
            /** 转移manifest文件 */
            fs$1.mkdir(path.join(root + assets), function (err) {
                if (err) {
                    return console.error(err);
                }
                fs$1.renameSync(path.join("".concat(outDir, "/rev-manifest.json")), path.join("".concat(root).concat(assets, "/rev-manifest.json")));
            });
        }
    };
}

var cwd = process.cwd();

var IMAGES_REGEXP = ['png', 'jpg', 'jpge', 'gif', 'svga'];
var initWinkeyConfig = function (winkeyConfig, viteConfig) {
    var _a, _b, _c, _d, _e, _f;
    var localConfig = winkeyConfig;
    /** 基础路径 */
    var BASE_PROJECT_PATH = ((_a = localConfig === null || localConfig === void 0 ? void 0 : localConfig.dest) === null || _a === void 0 ? void 0 : _a.basePath) || './';
    /** css文件路径 */
    var CSS_PATH = ((_b = localConfig === null || localConfig === void 0 ? void 0 : localConfig.dest) === null || _b === void 0 ? void 0 : _b.cssPath) || 'css';
    /** js文件路径 */
    var JS_PATH = ((_c = localConfig === null || localConfig === void 0 ? void 0 : localConfig.dest) === null || _c === void 0 ? void 0 : _c.jsPath) || 'js';
    /** html文件路径 */
    var HTML_PATH = ((_d = localConfig === null || localConfig === void 0 ? void 0 : localConfig.dest) === null || _d === void 0 ? void 0 : _d.htmlPath) || 'html';
    /** 图片文件路径 */
    var IMG_PATH = ((_e = localConfig === null || localConfig === void 0 ? void 0 : localConfig.dest) === null || _e === void 0 ? void 0 : _e.imagesPath) || 'images';
    /** alias 基础路径 */
    var ALIAS_ROOT_PATH = (localConfig === null || localConfig === void 0 ? void 0 : localConfig.alias).srcRoot || './src/';
    /** 输出目录 */
    var OUTDIR_PATH = (localConfig === null || localConfig === void 0 ? void 0 : localConfig.outDir) || './dist/';
    var config = {
        /** 根目录 */
        root: localConfig.root || './',
        // /** 存储缓存文件的目录。 */
        cacheDir: localConfig.cacheDir || 'node_modules/.vite',
        clearScreen: localConfig.clearScreen || false,
        /** 出口文件 */
        build: {
            outDir: path.join(cwd, OUTDIR_PATH),
            emptyOutDir: true,
            manifest: 'rev-manifest.json',
            assetsInlineLimit: 4096,
            rollupOptions: {
                output: {
                    entryFileNames: BASE_PROJECT_PATH + 'js/[name]-[hash].js',
                    assetFileNames: function (val) {
                        var _a;
                        var works = (_a = val.name) === null || _a === void 0 ? void 0 : _a.split('.');
                        if (works) {
                            var type = works[works.length - 1];
                            if (type === 'css') {
                                return BASE_PROJECT_PATH + CSS_PATH + '/[name]-[hash].[ext]';
                            }
                            if (type === 'js') {
                                return BASE_PROJECT_PATH + JS_PATH + '/[name]-[hash].[ext]';
                            }
                            if (IMAGES_REGEXP.includes(type)) {
                                return BASE_PROJECT_PATH + IMG_PATH + '/[name]-[hash].[ext]';
                            }
                        }
                        var ext = 'assets';
                        return BASE_PROJECT_PATH + ext + '/[name]-[hash].[ext]';
                    }
                }
            }
        },
        /** 开发配置 */
        server: {
            host: '0.0.0.0',
            port: ((_f = localConfig.server) === null || _f === void 0 ? void 0 : _f.port) || 5000
        },
        /** 路径设置 */
        resolve: {
            alias: Array.isArray(localConfig === null || localConfig === void 0 ? void 0 : localConfig.alias)
                ? localConfig.alias
                : [
                    {
                        find: '~@',
                        replacement: path.join(ALIAS_ROOT_PATH + 'components/')
                    },
                    {
                        find: '~',
                        replacement: path.join(ALIAS_ROOT_PATH)
                    }
                ]
        },
        /** 导入 .css 文件将会把内容插入到 <style> 标签中，同时也带有 HMR 支持。也能够以字符串的形式检索处理后的、作为其模块默认导出的 CSS。 */
        css: {
            modules: localConfig.cssModules
                ? {
                    // css模块化 文件以.module.[css|less|scss]结尾
                    generateScopedName: '[name]__[local]___[hash:base64:5]',
                    hashPrefix: 'winkey'
                }
                : false,
            /** 指定传递给 CSS 预处理器的选项。文件扩展名用作选项的键 */
            preprocessorOptions: {
                less: {
                    /** 支持内敛JavaScript */
                    javascriptEnabled: true
                },
                scss: {
                    /** 支持内敛JavaScript */
                    javascriptEnabled: true
                }
            }
        },
        /** 插件 */
        plugins: [
            legacy({
                targets: ['Android >= 39', 'Chrome >= 39', 'Safari >= 10.1', 'iOS >= 10', '> 0.5%'],
                polyfills: ['es.promise', 'regenerator-runtime']
            }),
            eslintPlugin({
                include: ['src/**/*.ts', 'src/**/*.tsx', 'src/*.ts', 'src/*.tsx']
            }),
            modifyDistPath({
                root: OUTDIR_PATH + BASE_PROJECT_PATH,
                outDir: OUTDIR_PATH,
                html: HTML_PATH,
                assets: '/assets'
            }),
            react(),
            tsconfigPaths(),
            StylelintPlugin({
                fix: true,
                quiet: true
            })
        ]
    };
    /** 合并plugin */
    config.plugins = Object.assign(config.plugins, localConfig.plugins || []);
    /** 合并css */
    config.css = Object.assign(config.css, localConfig.css || {});
    var _g = viteConfig, mode = _g.mode, command = _g.command;
    var env = loadEnv(mode, process.cwd());
    var isBuild = command === 'build';
    if (isBuild) {
        config.base = '/' + BASE_PROJECT_PATH;
        // 压缩 Html 插件
        config.define = {
            'process.env.NODE_ENV': '"production"'
        };
    }
    else {
        config.plugins = __spreadArray(__spreadArray([], config.plugins, true), [
            vitePluginHtml.createHtmlPlugin({
                inject: {
                    data: __assign(__assign({}, env), { devServerToolScript: "<script type=\"module\" src=\"/winkey_tool/js/index.js\"></script>", devServerToolCss: "<link href=\"/winkey_tool/css/index.css\" rel=\"stylesheet\" >" })
                }
            })
        ], false);
    }
    return config;
};

exports.initWinkeyConfig = initWinkeyConfig;
